==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebFormDataDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFormDataDescription } from "./WebFormDataDescription";
/**
 * @hidden
 */
export let WebFormDataDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFormDataDescriptionMetadata extends Base {
        static b(a) {
            if (WebFormDataDescriptionMetadata.a == null) {
                WebFormDataDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFormDataDescriptionMetadata.c(WebFormDataDescriptionMetadata.a);
            }
            if (a.j(WebFormDataDescriptionMetadata.a)) {
                return;
            }
            a.y(WebFormDataDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FormData");
            a.item("Keys", "Array:object");
            a.item("Values", "Array:object");
        }
        static d(a) {
            WebFormDataDescriptionMetadata.b(a);
            a.aa("WebFormData", () => new WebFormDataDescription());
            a.z("WebFormData", WebFormDataDescriptionMetadata.a);
        }
    }
    WebFormDataDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFormDataDescriptionMetadata, 'WebFormDataDescriptionMetadata');
    WebFormDataDescriptionMetadata.a = null;
    return WebFormDataDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebFormDataDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFormDataDescription } from "./WebFormDataDescription";
/**
 * @hidden
 */
export let WebFormDataDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFormDataDescriptionMetadata extends Base {
        static b(a) {
            if (WebFormDataDescriptionMetadata.a == null) {
                WebFormDataDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFormDataDescriptionMetadata.c(WebFormDataDescriptionMetadata.a);
            }
            if (a.k(WebFormDataDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebFormDataDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FormData");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Keys", "Array:object");
            a.item("Values", "Array:object");
        }
        static d(a) {
            WebFormDataDescriptionMetadata.b(a);
            a.ac("WebFormData", () => new WebFormDataDescription());
            a.ab("WebFormData", WebFormDataDescriptionMetadata.a);
        }
    }
    WebFormDataDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFormDataDescriptionMetadata, 'WebFormDataDescriptionMetadata');
    WebFormDataDescriptionMetadata.a = null;
    return WebFormDataDescriptionMetadata;
})();
